@@ -570,12 +570,15 @@ static long long get_freespace()
 		return(-1);
 	}
 
-	while ((mnt = getmntent(fp)))
+	while((mnt = getmntent(fp)))
 	{
 		struct statvfs64 buf;
 
-		statvfs64(mnt->mnt_dir, &buf);
-		ret += buf.f_bavail * buf.f_bsize;
+		if(strcmp(mnt->mnt_type, "samba")
+		   || strcmp(mnt->mnt_type, "nfs")) {
+			statvfs64(mnt->mnt_dir, &buf);
+			ret += buf.f_bavail * buf.f_bsize;
+		}
 	}
 
 	endmntent(fp);
